<?php

/**
 * @file This file maps the SOAP datatypes to PHP classes.
 */


/**
 * Our custom SOAP class to ensure the XML is in the same format that OMS requires.
 */
class CommerceOMSSoapClient extends SoapClient
{
  public function __doRequest($request, $location, $action, $version) {
    preg_match('|xmlns:ns1="(.*)"|', $request, $matches);
    $namespace = $matches[1];

    $request = str_replace('SOAP-ENV', 'soap', $request);
    $request = preg_replace('/<ns1:(\w+)/', '<$1 xmlns="'.$namespace.'"', $request, 1);
    $request = preg_replace('/<ns1:(\w+)/', '<$1', $request);
    $request = str_replace(array('/ns1:', 'xmlns:ns1="'.$namespace.'"'), array('/', ''), $request);

    return parent::__doRequest($request, $location, $action, $version);
  }
}


/**
 * CreateSalesOrder
 *
 * @see https://ws.ordermanagementsystems.com.au/omsordertaker/omsordertaker.asmx?op=CreateSalesOrder
 */
class CreateSalesOrder {
  public $LiveMode;
  public $order;
}


/**
 * SalesOrder
 *
 * This is a complex type defined by CreateSalesOrder. This class lists all the properties as required by
 * the SOAP WSDL, and sets some sensible defaults and data types.
 *
 * @see https://ws.ordermanagementsystems.com.au/omsordertaker/omsordertaker.asmx?op=CreateSalesOrder
 */
class SalesOrder {
  public $TransCode;
  public $AuthCode;
  public $Status = 'Processing';
  public $Origin = 'Other'; // set to Drupal eventually

  public $EmailAddress;
  public $ExternalID;
  public $ClientRoleName = 'Web Customers';
  public $RefID = 0;

  public $B2BCustomerName;
  public $B2BCustomerEmail;
  public $B2BCustomerPassword;


  // Bill to
  public $BillToCompany;
  public $BillToFName;
  public $BillToLName;
  public $BillToAddress1;
  public $BillToAddress2;
  public $BillToCity;
  public $BillToState;
  public $BillToZip;
  public $BillToCountry;
  public $BillToPhone;
  public $BillToResidential = TRUE;
  public $ShipToSameAsBillTo;

  // Shop to
  public $ShipToCompany;
  public $ShipToFName;
  public $ShipToLName;
  public $ShipToAddress1;
  public $ShipToAddress2;
  public $ShipToCity;
  public $ShipToState;
  public $ShipToZip;
  public $ShipToCountry;
  public $ShipToPhone;
  public $ShipToResidential = TRUE;

  // Other
  public $OrderDate;
  public $RequestedShipDate = 0;
  public $RequestedDeliveryDate = 0;
  public $MerchantPONumber;
  public $MerchantOrderNumber;
  public $Comments;
  public $PricingDiscount = 0.00;
  public $CouponDiscount = 0.00;
  public $Handling = 0.00;
  public $FlatRateShipping = 0.00;
  public $Tax = 0.00;
  public $ShipFee = 0.00;
  public $ShipMethod;
  public $ShipAccount;
  public $POTerm = 'Net-10';
  public $Priority = 'Low';
  public $ReferrerName;
  public $PaymentType;
  public $NameOnCard;
  public $CreditCardNumber;
  public $CreditCardExpMon = 0;
  public $CreditCardExpYr = 0;
  public $OptIn = FALSE;
  public $EmailCustomer = FALSE;
  public $BillToShipTo3PLID;
  public $Currency;
  public $Language;
  public $CheckForDuplicates = TRUE;
  public $HoursForDuplicateCheck = 48;
  public $OrderLineItems;
  public $OrderPayments;
  public $OrderComments;
  public $ValidateOnlyMOrderID = TRUE;
  public $LoginClientUserRoleID = 0;
  public $IPAddress;
  public $ShipToEmailAddress;
  public $NIPNumber;
  public $CheckOverrideLineItemTotal = FALSE;
  public $OverrideLineItemTotalAmount = 0;

  // EDI
  public $EDI_TransactionType;
  public $EDI_EmailClient = TRUE;
  public $EDI_FileName;
  public $EDI_NotBefore = 0;
  public $EDI_CancelAfter = 0;
  public $EDI_Description1;
  public $EDI_Description2;
  public $EDI_Description3;
  public $EDI_Description4;
  public $EDI_Description5;
}


/**
 * OrderLineItem
 *
 * This is a complex type defined by CreateSalesOrder representing the lineitems
 * for this order.
 *
 * This class lists all the properties as required by
 * the SOAP WSDL, and sets some sensible defaults and data types.
 *
 * @see https://ws.ordermanagementsystems.com.au/omsordertaker/omsordertaker.asmx?op=CreateSalesOrder
 */
class OrderLineItem {
  public $LineNumber;
  public $ItemName;
  public $QuantityOrdered;
  public $SKU;
  public $SKUWMS;
  public $UnitPrice;
  public $UnitPriceDiscount = 0;
  public $WarehouseName;
  public $OrderLineItem3PLID;
  public $ItemBarCode;
  public $Warehouse3PLID;
  public $SubInventory3PLID;
  public $BuyLoc;
  public $ShipLoc;
}
